metrics_scoring_rule module
===========================

This section contains the Python API reference for the
``uncertainty_toolbox.metrics_scoring_rule`` module, which contains code for uncertainty
metrics involving scoring rules.

uncertainty_toolbox.metrics_scoring_rule Module
###############################################

.. automodule:: uncertainty_toolbox.metrics_scoring_rule
    :members:
